# vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:

# Copyright 2022 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
#
# This file is part of qutebrowser.
#
# qutebrowser is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# qutebrowser is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with qutebrowser.  If not, see <https://www.gnu.org/licenses/>.

"""Tests for qutebrowser.commands.cmdexc."""

import re
import pytest

from qutebrowser.commands import cmdexc


def test_empty_command_error():
    with pytest.raises(cmdexc.NoSuchCommandError, match="No command given"):
        raise cmdexc.EmptyCommandError


@pytest.mark.parametrize("all_commands, msg", [
    ([], "testcmd: no such command"),
    (["fastcmd"], "testcmd: no such command (did you mean :fastcmd?)"),
    (["thisdoesnotmatch"], "testcmd: no such command"),
])
def test_no_such_command_error(all_commands, msg):
    with pytest.raises(cmdexc.NoSuchCommandError, match=re.escape(msg)):
        raise cmdexc.NoSuchCommandError.for_cmd("testcmd", all_commands=all_commands)
